use v6;
use PDF::Font::CIDFont;

class PDF::Font::CIDFontType2
    is PDF::Font::CIDFont {

}
